@@ -16,7 +16,7 @@
 /* First we define the version string
    Please change it, if you modify the source */
 
-#define VER "1.1"
+#define VER "1.2"
 
 
 /* Then we define the symbols you might want to change */
@@ -35,10 +35,17 @@
 /* if COLOUR is defined as nonzero colour support is enabled */
 /* :-) but it is slower */
 
+#ifndef COLOUR
 #define COLOUR 0
+#endif
+
+/* if AA is defined as nonzero antialiasing is enabled */
+/* it is only useful in 256 or more color modes */ 
+
+#define AA 0
 
 /* INIMAG is the initial magnification */
-#define INIMAG  (-3)
+#define INIMAG  (-2)
 
 /* PAPER<number> and INK<number> stands for paper and ink color respectively
    The <number> means number of bits per pixel. Currently paper is white and
@@ -65,7 +72,7 @@
 */
 
 #define GSRESLEN 10
-#define GSRES "-r240x216"
+#define GSRES "-r120x108"
 
 /* GSNAME is a name to invoke GS, it should be absolute, but it can point to
    a script, provided it passes all the arguments to GS */
