@@ -347,7 +347,7 @@ int force;
 	int86(0x10, &regs, &regs);
 #else
 	if(ioctl(screen_fd, SW_VGA12, 0L) == -1)
-		return quit("SW_VGA12");
+		return quit("console_grpahics_mode: SW_VGA12");
 #endif
 
 #if CONSOLE_DEBUG
@@ -392,7 +392,7 @@ int force;
 		in_graphics_mode, force);
 #endif
 
-	if (!in_graphics_mode && !force)
+	if (screen_fd == -1 || (!in_graphics_mode && !force))
 		return(0);
 
 	protect_disk();
@@ -416,7 +416,7 @@ int force;
 	if (!ok &&
 	    text_mode != 0 &&
 	    ioctl(screen_fd, MODESWITCH|text_mode, 0L) == -1) {
-		return quit("ioctl");
+		return quit("console_text_mode: ioctl: MODESWITCH");
 	}
 #endif
 
@@ -623,7 +623,8 @@ console_init(void (*repaint)(void))
 #   endif
 #else
 		screen_fd = open("/dev/tty", O_RDWR);
-		if (screen_fd == -1) return quit("/dev/tty");
+		if (screen_fd == -1)
+			return quit("console_init: open: /dev/tty");
 
 		if (ioctl(screen_fd, GIO_FONT8x16, font_data) == -1) {
 #ifdef TEST_MAIN
@@ -631,13 +632,13 @@ console_init(void (*repaint)(void))
 			if (screen_fd == -1) return quit("/dev/vga");
 			if (ioctl(screen_fd, GIO_FONT8x16, font_data) == -1)
 #endif
-				return quit("get font");
+				return quit("console_init: ioctl: get font");
 		}
 #endif
 
 		if (console_read_font() != 0) {
 #if MSDOS
-			return quit("console_read_font");
+			return quit("console_init: console_read_font");
 #endif
 		}
 
@@ -695,7 +696,7 @@ console_init(void (*repaint)(void))
 #ifdef MSDOS
 #else
 	if ( -1 == ioctl(screen_fd, VGA_IOPRIVL, 1L) )
-		return quit("VGA_IOPRIVL");
+		return quit("console_init: ioctl: VGA_IOPRIVL");
 #endif
 
 	console_graphics_mode(FALSE);
@@ -703,7 +704,7 @@ console_init(void (*repaint)(void))
 #ifdef MSDOS
 #else
 	if(0 == (screen_mem = (char *)ioctl(screen_fd, MAPCONS, 0L)))
-		return quit("MAPCONS");
+		return quit("console_init: ioctl: MAPCONS");
 
 	mode.mode = VT_PROCESS;
 	mode.waitv = 0;
@@ -712,7 +713,7 @@ console_init(void (*repaint)(void))
 	mode.frsig = SIGINT;
 
 	if (ioctl(screen_fd, VT_SETMODE, &mode) == -1)
-		return quit("VT_SETMODE");
+		return quit("console_init: ioctl: VT_SETMODE");
 
 	signal(SIG_RELEASE, release);
 	signal(SIG_ACQUIRE, acquire);
@@ -782,7 +783,7 @@ console_finish(void)
 	mode.frsig = SIGINT;
 
 	if (ioctl(screen_fd, VT_SETMODE, &mode) == -1)
-		quit("VT_SETMODE auto");
+		quit("console_finish: ioctl: VT_SETMODE auto");
 
 	signal(SIG_RELEASE, SIG_IGN);
 	signal(SIG_ACQUIRE, SIG_IGN);
@@ -1266,8 +1267,7 @@ static void console_dot(int color, register int x, register int y)
 
 	out_index2(GC_INDEX, GC_MASK, mask);
 
-	console_volatile x = *byte;	/* HW magic, must read video, x is not important
-  */
+	console_volatile x = *byte;	/* HW magic, must read video, x is not important     */
 			/* see: page 154 of EGA/VGA A programmer's Ref Guide */
 	*byte = (char) color;
 }
@@ -1695,6 +1695,11 @@ int main(int argc, char *argv[])
 
 	console_finish();
 
+	/* Check that extra calls do not do any damage */
+
+	console_text_mode(TRUE);
+	console_finish();
+
 	return(EXIT_SUCCESS);
 }
 
