@@ -19,7 +19,11 @@
 #include <sys/time.h>       /* because of FD_SETSIZE */
 #include <string.h>
 #include <ctype.h>
+#ifdef __linux__
 #include <linux/vt.h>
+#else
+#include <sys/vt.h>
+#endif
 
 /* the following variables local to this file contain the information about
    the videomode being used and what colours to use */
@@ -276,7 +280,13 @@ void showwindow(int mag,int windowx,int windowy)
 	if (pixperbyte != 8) {
 	/* for colour modes - each byte in outbuff represents one screen pixel */
 	  for(p=inbuff,r=outbuff;p<inbuff+windoww/imbits;p++)
-	    { col = (*p > thresh) ? inkcol : papercol ;
+	    { 
+	      #if AA
+	       col = 31 - (*p * 15 / imbits * imbits) ;
+	      #else 
+	       col = (*p > thresh) ? inkcol : papercol ;
+	      #endif
+	       
 	      for (k=0;k<scrbits;k++) *r++=col ; }
 	} else {
 	/* monochrome modes -each byte in outbuff represents eight screen pixels */
@@ -520,7 +530,7 @@ void displayfile(const char *filename)
                      goto readchar ;
 
           case 'P' : if (psview && usedsc && numpage>1)
-                                { numpage=0 ; cont=0 ; break ; }
+                                { numpage=1 ; cont=0 ; break ; }
                      goto readchar ;
 
           /* g reads PAGNOLEN digits and goes to that page */
@@ -536,7 +546,10 @@ void displayfile(const char *filename)
 		           else goto readchar ;
 		     }
 		     
-          /* c switches to other virtual consoles */		     
+          /* s switches to other virtual consoles */		     
+#ifdef M_UNIX
+          /* Under SCO this compiles but crashes due to kernel bugs */
+#else           
 	  case 's' : { char c ; int consolefd ;
  	  	       c=getchar() ;
 	  	       if (!isdigit(c)) goto readchar ; 
@@ -546,9 +559,13 @@ void displayfile(const char *filename)
 	  	       vga_unlockvc() ;
                        
                        printf("Switching to virtual console %d.\n",c-'0') ;
-                       if ((consolefd=open("/dev/console",O_RDWR))==-1)
+#if 0                   
+                       if ((consolefd=open("/dev/console",O_WRONLY))==-1)
                         leave(1,"Cannot open /dev/console",strerror(errno),NULL) ;
-                           
+#else                           
+                       if ((consolefd=open("/dev/tty",O_WRONLY))==-1)
+                        leave(1,"Cannot open /dev/tty",strerror(errno),NULL) ;
+#endif
 	  	       ioctl(consolefd,VT_ACTIVATE,c-'0') ;
 	  	       vga_lockvc() ;
 	  	       signal(SIGREADY,sighandler) ;
@@ -556,7 +573,7 @@ void displayfile(const char *filename)
 	  	       vga_setmode(vidmode) ;
 	  	       break ;
 	  	     }  	     	
-	  
+#endif	  
 	  default : goto readchar ;
                     }
 
